@@ -14,6 +14,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from mock import mock_open
+from mock import patch
 import sys
 
 from tackerclient.tacker.v1_0.vnfm import vnfd
@@ -28,7 +30,10 @@ class CLITestV10VmVNFDJSON(test_cli10.CLITestV10Base):
         plurals = {'vnfds': 'vnfd'}
         super(CLITestV10VmVNFDJSON, self).setUp(plurals=plurals)
 
-    def test_create_vnfd_all_params(self):
+    @patch("tackerclient.tacker.v1_0.vnfm.vnfd.open",
+           side_effect=mock_open(read_data="vnfd"),
+           create=True)
+    def test_create_vnfd_all_params(self, mo):
         cmd = vnfd.CreateVNFD(
             test_cli10.MyApp(sys.stdout), None)
         my_id = 'my-id'
@@ -37,7 +42,7 @@ class CLITestV10VmVNFDJSON(test_cli10.CLITestV10Base):
         attr_val = 'vnfd'
         args = [
             name,
-            '--vnfd', 'vnfd'
+            '--vnfd-file', 'vnfd-file'
         ]
         position_names = ['name']
         position_values = [name]
@@ -49,12 +54,15 @@ class CLITestV10VmVNFDJSON(test_cli10.CLITestV10Base):
                                    args, position_names, position_values,
                                    extra_body=extra_body)
 
-    def test_create_vnfd_with_mandatory_params(self):
+    @patch("tackerclient.tacker.v1_0.vnfm.vnfd.open",
+           side_effect=mock_open(read_data="vnfd"),
+           create=True)
+    def test_create_vnfd_with_mandatory_params(self, mo):
         cmd = vnfd.CreateVNFD(
             test_cli10.MyApp(sys.stdout), None)
         name = 'my_name'
         my_id = 'my-id'
-        args = [name, '--vnfd', 'vnfd', ]
+        args = [name, '--vnfd-file', 'vnfd-file', ]
         position_names = ['name']
         position_values = [name]
         extra_body = {
